@@ -114,6 +114,20 @@ defaults = {
 
                     'paned_position': 200,
                     'episode_list_size': 200,
+
+                    'episode_column_sort_id': 0,
+                    'episode_column_sort_order': False,
+                    'episode_column_order': [],
+                },
+                'preferences': {
+                    'width': -1,
+                    'height': -1,
+                    'x': -1, 'y': -1, 'maximized': False,
+                },
+                'config_editor': {
+                    'width': -1,
+                    'height': -1,
+                    'x': -1, 'y': -1, 'maximized': False,
                 },
                 'episode_selector': {
                     'width': 600,
@@ -135,6 +149,7 @@ defaults = {
             'toolbar': False,
             'new_episodes': 'show',  # ignore, show, queue, download
             'live_search_delay': 200,
+            'search_always_visible': False,
 
             'podcast_list': {
                 'all_episodes': True,
@@ -188,7 +203,8 @@ defaults = {
     'youtube': {
         'preferred_fmt_id': 18,  # default fmt_id (see fallbacks in youtube.py)
         'preferred_fmt_ids': [],  # for advanced uses (custom fallback sequence)
-        'api_key_v3': '',  # API key, register for one at https://developers.google.com/youtube/v3/
+        'preferred_hls_fmt_id': 93,  # default fmt_id (see fallbacks in youtube.py)
+        'preferred_hls_fmt_ids': [],  # for advanced uses (custom fallback sequence)
     },
 
     'vimeo': {
