@@ -28,7 +28,8 @@ from html.parser import HTMLParser
 from urllib.error import HTTPError
 
 import podcastparser
-from gpodder import util
+
+from gpodder import util, youtube
 
 logger = logging.getLogger(__name__)
 
@@ -84,7 +85,7 @@ class AuthenticationRequired(Exception):
 
 
 # Successful status codes
-UPDATED_FEED, NEW_LOCATION, NOT_MODIFIED, CUSTOM_FEED = list(range(4))
+UPDATED_FEED, NEW_LOCATION, NOT_MODIFIED = list(range(3))
 
 
 class Result:
@@ -104,13 +105,19 @@ class FeedAutodiscovery(HTMLParser):
             attrs = dict(attrs)
 
             is_feed = attrs.get('type', '') in Fetcher.FEED_TYPES
+            is_youtube = 'youtube.com' in self._base
             is_alternate = attrs.get('rel', '') == 'alternate'
+            is_canonical = attrs.get('rel', '') == 'canonical'
             url = attrs.get('href', None)
             url = urllib.parse.urljoin(self._base, url)
 
             if is_feed and is_alternate and url:
                 logger.info('Feed autodiscovery: %s', url)
                 self._resolved_url = url
+            elif is_youtube and is_canonical and url:
+                url = youtube.parse_youtube_url(url)
+                logger.info('Feed autodiscovery: %s', url)
+                self._resolved_url = url
 
 
 class Fetcher(object):
@@ -173,7 +180,7 @@ class Fetcher(object):
         else:
             raise UnknownStatusCode(status)
 
-    def _parse_feed(self, url, etag, modified, autodiscovery=True):
+    def _parse_feed(self, url, etag, modified, autodiscovery=True, max_episodes=0):
         headers = {}
         if modified is not None:
             headers['If-Modified-Since'] = modified
@@ -203,23 +210,24 @@ class Fetcher(object):
             ad = FeedAutodiscovery(url)
 
             ad.feed(data.getvalue())
-            if ad._resolved_url:
+            if ad._resolved_url and ad._resolved_url != url:
                 try:
                     self._parse_feed(ad._resolved_url, None, None, False)
                     return Result(NEW_LOCATION, ad._resolved_url)
                 except Exception as e:
                     logger.warn('Feed autodiscovery failed', exc_info=True)
 
-                # Second, try to resolve the URL
-                url = self._resolve_url(url)
-                if url:
-                    return Result(NEW_LOCATION, url)
+            # Second, try to resolve the URL
+            new_url = self._resolve_url(url)
+            if new_url and new_url != url:
+                return Result(NEW_LOCATION, new_url)
 
             # Reset the stream so podcastparser can give it a go
             data.seek(0)
 
         try:
             feed = podcastparser.parse(url, data)
+            feed['url'] = url
         except ValueError as e:
             raise InvalidFeed('Could not parse feed: {msg}'.format(msg=e))
 
@@ -230,5 +238,5 @@ class Fetcher(object):
             feed['headers'] = stream.headers
             return self._check_statuscode(stream, feed)
 
-    def fetch(self, url, etag=None, modified=None):
-        return self._parse_feed(url, etag, modified)
+    def fetch(self, url, etag=None, modified=None, max_episodes=0):
+        return self._parse_feed(url, etag, modified, max_episodes)
