@@ -651,6 +651,7 @@ class HyperlinkExtracter(object):
     def __init__(self):
         self.parts = []
         self.target_stack = [None]
+        self.ignore_data = False
 
     def get_result(self):
         # Group together multiple consecutive parts with same link target,
@@ -698,11 +699,18 @@ class HyperlinkExtracter(object):
         if len(self.target_stack) > 1:
             self.target_stack.pop()
 
+    def handle_start_style(self, attrs):
+        self.ignore_data = True
+
+    def handle_end_style(self):
+        self.ignore_data = False
+
     def output(self, text):
         self.parts.append((self.target_stack[-1], text))
 
     def handle_data(self, data):
-        self.output(self.htmlws(data))
+        if not self.ignore_data:
+            self.output(self.htmlws(data))
 
     def handle_entityref(self, name):
         c = chr(name2codepoint[name])
@@ -1644,7 +1652,7 @@ def relpath(p1, p2):
     if len(l1) > 0:
         p = [('..' + os.sep) * len(l1)]
     p = p + l2
-    if len(p) is 0:
+    if len(p) == 0:
         return "."
 
     return os.path.join(*p)
@@ -1831,7 +1839,7 @@ def linux_get_active_interfaces():
     """
     process = Popen(['ip', 'link'], close_fds=True, stdout=subprocess.PIPE)
     data, _ = process.communicate()
-    for interface, _ in re.findall(r'\d+: ([^:]+):.*state (UP|UNKNOWN)', data.decode(locale.getpreferredencoding())):
+    for interface, _ in re.findall(r'\d+: ([^:]+):.*state (UP|DORMANT|UNKNOWN)', data.decode(locale.getpreferredencoding())):
         if interface != 'lo':
             yield interface
 
