@@ -23,18 +23,17 @@
 #
 
 
+import json
+import logging
+import re
+
 import gpodder
+from gpodder import registry, util
 
 _ = gpodder.gettext
 
-from gpodder import util
-
-import logging
 logger = logging.getLogger(__name__)
 
-import json
-
-import re
 
 VIMEOCOM_RE = re.compile(r'http[s]?://vimeo\.com/(channels/[^/]+|\d+)$', re.IGNORECASE)
 VIMEOCOM_VIDEO_RE = re.compile(r'http[s]?://vimeo.com/channels/(?:[^/])+/(\d+)$', re.IGNORECASE)
@@ -50,6 +49,13 @@ FORMATS = tuple((x, x) for x in FILEFORMAT_RANKING)
 class VimeoError(BaseException): pass
 
 
+@registry.download_url.register
+def vimeo_real_download_url(config, episode, allow_partial):
+    fmt = config.vimeo.fileformat if config else None
+    res = get_real_download_url(episode.url, preferred_fileformat=fmt)
+    return None if res == episode.url else res
+
+
 def get_real_download_url(url, preferred_fileformat=None):
     video_id = get_vimeo_id(url)
 
