@@ -41,6 +41,7 @@ DefaultConfig = {
 
 # youtube feed still preprocessed by youtube.py (compat)
 CHANNEL_RE = re.compile(r'''https://www.youtube.com/feeds/videos.xml\?channel_id=(.+)''')
+USER_RE = re.compile(r'''https://www.youtube.com/feeds/videos.xml\?user=(.+)''')
 PLAYLIST_RE = re.compile(r'''https://www.youtube.com/feeds/videos.xml\?playlist_id=(.+)''')
 
 
@@ -80,27 +81,39 @@ class YoutubeCustomDownload(download.CustomDownload):
         called by download.DownloadTask to perform the download.
         """
         self._reporthook = reporthook
-        res = self._ytdl.fetch_video(self._url, tempname, self._my_hook)
+        # outtmpl: use given tempname by DownloadTask
+        # (escape % and $ because outtmpl used as a string template by youtube-dl)
+        outtmpl = tempname.replace('%', '%%').replace('$', '$$')
+        res = self._ytdl.fetch_video(self._url, outtmpl, self._my_hook)
+        if outtmpl != tempname:
+            if 'ext' in res and os.path.isfile(outtmpl + '.{}'.format(res['ext'])):
+                os.rename(outtmpl + '.{}'.format(res['ext']), tempname)
+            else:
+                os.rename(outtmpl, tempname)
         if 'duration' in res and res['duration']:
             self._episode.total_time = res['duration']
         headers = {}
         # youtube-dl doesn't return a content-type but an extension
         if 'ext' in res:
             dot_ext = '.{}'.format(res['ext'])
+            # See #673 when merging multiple formats, the extension is appended to the tempname
+            # by YoutubeDL resulting in empty .partial file + .partial.mp4 exists
+            # and #796 .mkv is chosen by ytdl sometimes
+            tempstat = os.stat(tempname)
+            if not tempstat.st_size:
+                for try_ext in (dot_ext, ".mp4", ".m4a", ".webm", ".mkv"):
+                    tempname_with_ext = tempname + try_ext
+                    if os.path.isfile(tempname_with_ext):
+                        logger.debug('Youtubedl downloaded to "%s" instead of "%s", moving',
+                                     os.path.basename(tempname_with_ext),
+                                     os.path.basename(tempname))
+                        os.remove(tempname)
+                        os.rename(tempname_with_ext, tempname)
+                        dot_ext = try_ext
+                        break
             ext_filetype = mimetype_from_extension(dot_ext)
             if ext_filetype:
                 headers['content-type'] = ext_filetype
-            # See #673 when merging multiple formats, the extension is appended to the tempname
-            # by YoutubeDL resulting in empty .partial file + .partial.mp4 exists
-            tempstat = os.stat(tempname)
-            if not tempstat.st_size:
-                tempname_with_ext = tempname + dot_ext
-                if os.path.isfile(tempname_with_ext):
-                    logger.debug('Youtubedl downloaded to %s instead of %s, moving',
-                                 os.path.basename(tempname),
-                                 os.path.basename(tempname_with_ext))
-                    os.remove(tempname)
-                    os.rename(tempname_with_ext, tempname)
         return headers, res.get('url', self._url)
 
     def _my_hook(self, d):
@@ -139,7 +152,7 @@ class YoutubeFeed(model.Feed):
         filtered_entries = []
         seen_guids = set()
         for i, e in enumerate(entries):  # consumes the generator!
-            if e.get('_type', 'video') == 'url' and e.get('ie_key') == 'Youtube':
+            if e.get('_type', 'video') in ('url', 'url_transparent') and e.get('ie_key') == 'Youtube':
                 guid = video_guid(e['id'])
                 e['guid'] = guid
                 if guid in seen_guids:
@@ -251,8 +264,13 @@ class YoutubeFeed(model.Feed):
 
 
 class gPodderYoutubeDL(download.CustomDownloader):
-    def __init__(self, gpodder_config=None):
+    def __init__(self, gpodder_config, my_config, force=False):
+        """
+        :param force: force using this downloader even if config says don't manage downloads
+        """
         self.gpodder_config = gpodder_config
+        self.my_config = my_config
+        self.force = force
         # cachedir is not much used in youtube-dl, but set it anyway
         cachedir = os.path.join(gpodder.home, 'youtube-dl')
         os.makedirs(cachedir, exist_ok=True)
@@ -282,7 +300,7 @@ class gPodderYoutubeDL(download.CustomDownloader):
         #
         # See https://github.com/ytdl-org/youtube-dl#format-selection for details
         # about youtube-dl format specification.
-        fmt_ids = youtube.get_fmt_ids(gpodder_config.youtube)
+        fmt_ids = youtube.get_fmt_ids(gpodder_config.youtube, False)
         opts['format'] = '/'.join(str(fmt) for fmt in fmt_ids)
         if fallback:
             opts['format'] += '/' + fallback
@@ -290,9 +308,7 @@ class gPodderYoutubeDL(download.CustomDownloader):
 
     def fetch_video(self, url, tempname, reporthook):
         opts = {
-            # outtmpl: use given tempname by DownloadTask
-            # (escape % and $ because outtmpl used as a string template by youtube-dl)
-            'outtmpl': tempname.replace('%', '%%').replace('$', '$$'),
+            'outtmpl': tempname,
             'nopart': True,  # don't append .part (already .partial)
             'retries': 3,  # retry a few times
             'progress_hooks': [reporthook]  # to notify UI
@@ -373,14 +389,20 @@ class gPodderYoutubeDL(download.CustomDownloader):
         called by model.gPodderFetcher to get a custom feed.
         :returns feedcore.Result: a YoutubeFeed or None if channel is not a youtube channel or playlist
         """
+        if not self.my_config.manage_channel:
+            return None
         url = None
         m = CHANNEL_RE.match(channel.url)
         if m:
-            url = 'https://www.youtube.com/channel/{}'.format(m.group(1))
+            url = 'https://www.youtube.com/channel/{}/videos'.format(m.group(1))
         else:
-            m = PLAYLIST_RE.match(channel.url)
+            m = USER_RE.match(channel.url)
             if m:
-                url = 'https://www.youtube.com/playlist?list={}'.format(m.group(1))
+                url = 'https://www.youtube.com/user/{}/videos'.format(m.group(1))
+            else:
+                m = PLAYLIST_RE.match(channel.url)
+                if m:
+                    url = 'https://www.youtube.com/playlist?list={}'.format(m.group(1))
         if url:
             logger.info('Youtube-dl Handling %s => %s', channel.url, url)
             return self.refresh(url, channel.url, max_episodes)
@@ -390,6 +412,8 @@ class gPodderYoutubeDL(download.CustomDownloader):
         """
         called from registry.custom_downloader.resolve
         """
+        if not self.force and not self.my_config.manage_downloads:
+            return None
         if re.match(r'''https://www.youtube.com/watch\?v=.+''', episode.url):
             return YoutubeCustomDownload(self, episode.url, episode)
         elif re.match(r'''https://www.youtube.com/watch\?v=.+''', episode.link):
@@ -403,12 +427,10 @@ class gPodderExtension:
         self.ytdl = None
 
     def on_load(self):
-        self.ytdl = gPodderYoutubeDL(self.container.manager.core.config)
+        self.ytdl = gPodderYoutubeDL(self.container.manager.core.config, self.container.config)
         logger.info('Registering youtube-dl.')
-        if self.container.config.manage_channel:
-            registry.feed_handler.register(self.ytdl.fetch_channel)
-        if self.container.config.manage_downloads:
-            registry.custom_downloader.register(self.ytdl.custom_downloader)
+        registry.feed_handler.register(self.ytdl.fetch_channel)
+        registry.custom_downloader.register(self.ytdl.custom_downloader)
 
     def on_unload(self):
         logger.info('Unregistering youtube-dl.')
@@ -432,4 +454,6 @@ class gPodderExtension:
             return [(_("Download with Youtube-DL"), self.download_episodes)]
 
     def download_episodes(self, episodes):
-        self.gpodder.download_episode_list(episodes, downloader=self.ytdl)
+        # create a new gPodderYoutubeDL to force using it even if manage_downloads is False
+        downloader = gPodderYoutubeDL(self.container.manager.core.config, self.container.config, force=True)
+        self.gpodder.download_episode_list(episodes, downloader=downloader)
